==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/ts/Draw_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Draw</name>
    <message>
        <location filename="../Draw.js" line="+61"/>
        <source>Draw</source>
        <translation>Desenhe</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Draw</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Desenho
&amp;Preferências do Desenho Atual...</translatorcomment>
        <translation>&amp;Desenhe</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangle</name>
    <message>
        <source>Top Left</source>
        <translation type="vanished">Esquerda Superior</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="vanished">Superior</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="vanished">Direita Superior</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Esquerda</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">Meio</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Direita</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="vanished">Esquerda Inferior</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="vanished">Inferior</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="vanished">Direita Inferior</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="vanished">Posição</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectanglePP</name>
    <message>
        <location filename="../DrawBasedOnRectanglePP.js" line="+63"/>
        <source>First corner</source>
        <translation>Primeiro vértice</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation>Segundo vértice</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangleSize</name>
    <message>
        <location filename="../DrawBasedOnRectangleSize.js" line="+46"/>
        <source>Top Left</source>
        <translation>Esquerda Superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top Right</source>
        <translation>Direita Superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Meio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Left</source>
        <translation>Esquerda Inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Right</source>
        <translation>Direita Inferior</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnThreeCircles</name>
    <message>
        <location filename="../DrawBasedOnThreeCircles.js" line="+72"/>
        <source>First arc or circle</source>
        <translation>Primeiro arco ou círculo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second arc or circle</source>
        <translation>Segundo arco ou círculo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Third arc or circle</source>
        <translation>Terceiro arco ou círculo</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/ts/Draw_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Draw</name>
    <message>
        <location filename="../Draw.js" line="+61"/>
        <source>Draw</source>
        <translation>Desenhe</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Draw</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Desenho
&amp;Preferências do Desenho Atual...</translatorcomment>
        <translation>&amp;Desenhe</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Drawing Tools</source>
        <translation>Ferramentas de Desenho</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangle</name>
    <message>
        <source>Top Left</source>
        <translation type="vanished">Esquerda Superior</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="vanished">Superior</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="vanished">Direita Superior</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Esquerda</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">Meio</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Direita</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="vanished">Esquerda Inferior</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="vanished">Inferior</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="vanished">Direita Inferior</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="vanished">Posição</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectanglePP</name>
    <message>
        <location filename="../DrawBasedOnRectanglePP.js" line="+69"/>
        <source>First corner</source>
        <translation>Primeiro vértice</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation>Segundo vértice</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangleSize</name>
    <message>
        <location filename="../DrawBasedOnRectangleSize.js" line="+46"/>
        <source>Top Left</source>
        <translation>Esquerda Superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top Right</source>
        <translation>Direita Superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Meio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Left</source>
        <translation>Esquerda Inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Right</source>
        <translation>Direita Inferior</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnThreeCircles</name>
    <message>
        <location filename="../DrawBasedOnThreeCircles.js" line="+72"/>
        <source>First arc or circle</source>
        <translation>Primeiro arco ou círculo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second arc or circle</source>
        <translation>Segundo arco ou círculo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Third arc or circle</source>
        <translation>Terceiro arco ou círculo</translation>
    </message>
</context>
</TS>
